@@ -8,8 +8,13 @@
  */
 
 package org.gnu.gnome;
+
 import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
 import org.gnu.gtk.Window;
+
+/**
+ */
 public class WindowIcon extends Boxed 
 {
 	// no instantiations
@@ -32,19 +37,15 @@ public class WindowIcon extends Boxed
 		gnome_window_icon_set_default_from_file( filename );
 	}
  		
- 	/****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
-    native static final protected void gnome_window_icon_set_from_default (int window);
-    native static final protected void gnome_window_icon_set_from_file (int window, String filename);
-    native static final protected void gnome_window_icon_set_from_file_list (int window, 
+
+    native static final protected void gnome_window_icon_set_from_default (Handle window);
+    native static final protected void gnome_window_icon_set_from_file (Handle window, String filename);
+    native static final protected void gnome_window_icon_set_from_file_list (Handle window, 
         String[] filenames);
     native static final protected void gnome_window_icon_set_default_from_file (String filename);
     native static final protected void gnome_window_icon_set_default_from_file_list (
         String[] filenames);
     native static final protected void gnome_window_icon_init ();
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+
 }
 
